package com.zopim.android.sdk.api;

import android.support.annotation.NonNull;
import com.zopim.android.sdk.prechat.EmailTranscript;
import com.zopim.android.sdk.prechat.PreChatForm;

/**
 * Chat configuration interface
 * <p>
 * Used to tell what is the chat configuration of the current chat session.
 * Configuration is passed during initialization and start of the chat.
 * </p>
 *
 * @see ZopimChatApi.DefaultConfig
 * @see ZopimChatApi.SessionConfig
 */
public interface ChatConfig extends ChatApiConfig {

    /**
     * Gets pre chat configuration form as configured at initialization
     * via {@link ZopimChatApi.DefaultConfig} or start of the chat via {@link ZopimChatApi.SessionConfig}
     *
     * @return pre chat form
     * @see PreChatForm
     */
    @NonNull
    PreChatForm getPreChatForm();

    /**
     * Gets the email transcript configuration as configured at initialization
     * via {@link ZopimChatApi.DefaultConfig} or start of the chat via {@link ZopimChatApi.SessionConfig}
     *
     * @return email transcript configuration
     * @See EmailTranscript
     */
    @NonNull
    EmailTranscript getEmailTranscript();

    /**
     * Gets if file sending support is enabled via. {@link ZopimChat.DefaultConfig}
     * or start of the chat view {@link ZopimChat.SessionConfig}
     *
     * @return {@code true} if file sending support is enabled,
     *          {@code false} if not
     */
    boolean isFileSendingEnabled();
}
