package com.zopim.android.sdk.api;

import android.support.annotation.NonNull;
import android.support.v4.app.FragmentActivity;
import com.zopim.android.sdk.data.DataSource;
import com.zopim.android.sdk.model.ChatLog;
import com.zopim.android.sdk.model.VisitorInfo;
import com.zopim.android.sdk.prechat.EmailTranscript;
import com.zopim.android.sdk.prechat.PreChatForm;
import java.io.File;

/**
 * Definition for initialization and configuration of the chat.
 * <p>
 * Firstly, to initialize the chat call {@link ZopimChat#init(String)} with the correct account key obtained at your Zopim account configuration page.
 * </p>
 * <p>
 * A global chat configuration can be provided at initialization which will apply to all chat sessions that get started.
 * Additionally, each chat session can be configured separately during chat start {@link ZopimChat#start(android.support.v4.app.FragmentActivity)}.
 * Starting a chat will provide an instance of {@link Chat} used for chat communication. That chat is the bound to the lifecycle of the activity that was used to start the chat.
 * </p>
 *
 * @see <a href="https://dashboard.zopim.com/#widget/getting_started">Getting Started</a>
 * @see Chat
 */
public class ZopimChat implements Chat {

    /**
     * Initiates chat and returns {@link ZopimChat.DefaultConfig} global configuration builder to be used for configuring the global chat settings.
     * This configuration will apply to all new instances of a chat session unless a new session configuration is provided when starting the new chat.
     *
     * @param accountKey Your account key obtained from the Zopim widget config page. Will configure chat to use your Zopim instance.
     * @return configuration builder for setting the global chat configuration
     */
    @NonNull
    public static DefaultConfig init(String accountKey) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Starts the chat with global configuration. Chat needs to be previously initialized.
     *
     * @param activity that holds the chat session
     * @return chat session instance
     */
    @NonNull
    public static synchronized Chat start(FragmentActivity activity) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Attempts to resume the existing chat if possible. Chat needs to be previously initialized.
     * <p>
     * Resuming a chat will be possible if the previous chat was not ended via {@link ZopimChat#endChat()} or expired.
     * Chat timeout time, defined here {@link ChatSession#DEFAULT_CHAT_SESSION_TIMEOUT} is the time that expired after the last message exchange.
     * If resuming was successful it will restore chat configuration from the server. If chat can not be resumed this will still return the chat instance but it won't be able to chat because it has ended {@link ZopimChat#hasEnded()}.
     * </p>
     * <p>
     * Resumed chat might not be immediately ready to communicate.
     * </p>
     *
     * @param activity that holds the chat session
     * @return chat session instance
     */
    @NonNull
    public static synchronized Chat resume(@SuppressWarnings("unused") FragmentActivity activity) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Set the push token.
     *
     * @param token the Google/FCM device token
     */
    public static void setPushToken(final String token) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Clear the push token.
     */
    public static void clearPushToken() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Leaves an event trace.
     * <p>
     * It is possible to track event prior chat session being started.
     * Tracked events will be sent as soon as chat session is connected and any further event after that point will be sent immediately.
     * </p>
     *
     * @param description of the event
     */
    public static void trackEvent(String description) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets chat data source defined in {@link com.zopim.android.sdk.data.DataSource} and {@link com.zopim.android.sdk.data.PathDataSource}
     * <p>
     * Data source provides subscription to data update broadcasts. It also enables to get current state of a data path.
     * </p>
     *
     * @return data source
     * @deprecated use {@link ZopimChatApi#getDataSource()} instead
     */
    @Deprecated
    public static DataSource getDataSource() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Configures the global {@link com.zopim.android.sdk.model.VisitorInfo}
     * <p>
     * Visitor info can be set at any point, but the changes will take effect at next chat session start
     * </p>
     *
     * @param visitorInfo visitor data from {@link com.zopim.android.sdk.model.VisitorInfo}
     */
    public static void setVisitorInfo(VisitorInfo visitorInfo) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets reconnect timeout that was configured via {@link ZopimChatApi.DefaultConfig#reconnectTimeout}
     * If timeout was not configured it will return the {@link ChatSession#DEFAULT_RECONNECT_TIMEOUT}
     *
     * @return reconnect timeout
     * @deprecated use {@link ZopimChatApi#getReconnectTimeout()} instead
     */
    @Deprecated
    public static Long getReconnectTimeout() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets initialization timeout that was configured via {@link ZopimChatApi.DefaultConfig#initializationTimeout}
     * If timeout was not configured it will return the {@link ChatSession#DEFAULT_CHAT_INITIALIZATION_TIMEOUT}
     *
     * @return initialization timeout
     * @deprecated use {@link ZopimChatApi#getInitializationTimeout()} instead
     */
    @Deprecated
    public static Long getInitializationTimeout() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @NonNull
    @Override
    public ChatConfig getConfig() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public boolean hasEnded() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void resetTimeout() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void send(String message) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void send(@NonNull File file) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void resend(String messageId) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public boolean sendOfflineMessage(String name, String email, String message) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void sendChatRating(@NonNull ChatLog.Rating rating) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void sendChatComment(@NonNull String comment) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public boolean emailTranscript(String email) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void endChat() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void disconnect() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void setDepartment(String department) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void setPhoneNumber(String phoneNumber) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void setName(String name) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void setEmail(String email) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void setNote(String note) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public void addNote(String note) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Configuration class for global chat configuration
     * <p>
     * Configuration specified here will be applicable to all chat sessions that get started. This configuration can be overridden by a {@link com.zopim.android.sdk.api.ZopimChat.SessionConfig} configuration provided when starting a new chat.
     * </p>
     *
     * @see com.zopim.android.sdk.api.ZopimChat.SessionConfig
     */
    public static class DefaultConfig extends ZopimChatApi.DefaultConfig<DefaultConfig> implements ConfigBuilder<DefaultConfig> {

        @NonNull
        public DefaultConfig preChatForm(PreChatForm preChatForm) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        public DefaultConfig emailTranscript(EmailTranscript emailTranscript) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        public DefaultConfig fileSending(final boolean enabled) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        @Override
        public DefaultConfig disableVisitorInfoStorage() {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        @Override
        public DefaultConfig initializationTimeout(long milliseconds) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        @Override
        public DefaultConfig reconnectTimeout(long milliseconds) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        @Override
        public DefaultConfig sessionTimeout(long milliseconds) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }
    }

    /**
     * Configuration class for session chat configuration
     * <p>
     * Prepares new chat session config. Provided configuration will apply only to this session.
     * Once configured call build() to return a {@link ZopimChat} instance to use.
     * </p>
     */
    public static class SessionConfig extends ZopimChatApi.SessionConfig<SessionConfig> implements ConfigBuilder<SessionConfig> {

        @NonNull
        @Override
        public SessionConfig department(String department) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        @Override
        public SessionConfig tags(String... tags) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        @Override
        public SessionConfig visitorPathOne(String visitorPath) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        @Override
        public SessionConfig visitorPathTwo(String visitorPath) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        public SessionConfig preChatForm(PreChatForm preChatForm) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        public SessionConfig emailTranscript(EmailTranscript emailTranscript) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        public SessionConfig fileSending(final boolean enabled) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        @Override
        public Chat build(@NonNull FragmentActivity activity) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }
    }
}
